#' Lecture et Fusion de Données Géographiques
#'
#' Cette fonction lit des données depuis un fichier Excel et un fichier shapefile, puis les fusionne en un seul data frame sf.
#'
#' @param varL list contenant les deux éléments à compararer pour fusioner les entrées
#' @param path Chemin vers le répertoire contenant les fichiers de données.
#' @param data Nom du fichier Excel contenant les données à lire.
#' @param shp Nom du fichier shapefile contenant les polygones géographiques.
#'
#' @import dplyr
#'
#' @return Un data frame sf fusionné contenant les données Excel et les polygones du shapefile.
#' @export
#'
#' @examples
#' \dontrun{
#' path <- "path/to/data"
#' data <- "datafile.xlsx"
#' shp <- "shapefile.shp"
#' df <- readData(path, data, shp)
#' }
readData <- function(varL = NULL, path, data, shp) {
  if (is.null(varL)) {
    message("Merci de renseigner la variable commune entre les données et le shapefile")
    stop()
  }

  df <- readxl::read_excel(file.path(path, data), sheet = 2, skip = 1)
  shp <- sf::st_read(file.path(path, shp)) %>% as.data.frame()

  ## Identification de la colonne incluant les noms de communes
  dfMerged <- shp %>%
    dplyr::left_join(df, by = setNames(varL$data, varL$shp)) %>%
    dplyr::mutate(!!getCommunes(df) := coalesce(!!sym(getCommunes(df)), !!sym(getCommunes(shp)))) %>%
    dplyr::rename(!!varL$data := varL$shp) %>%
    dplyr::select(all_of(c(names(df), "geometry")))

  dfMerged_sf <- sf::st_as_sf(dfMerged, sf_column_name = "geometry")

  return(dfMerged_sf)
}
